summaryrefslogtreecommitdiffstats
path: root/include/xmloff/txtparae.hxx
diff options
context:
space:
mode:
authorStephan Bergmann <sbergman@redhat.com>2014-09-30 08:13:36 +0200
committerStephan Bergmann <sbergman@redhat.com>2014-09-30 08:13:48 +0200
commit68daa8a22611605299ac3174a3632191f93236d9 (patch)
treefdfb7c512a61bf4543e056191dfeb3e6f276ac13 /include/xmloff/txtparae.hxx
parentWaE: implicit conversion of literal of type 'sal_Bool' to 'bool' (diff)
downloadcore-68daa8a22611605299ac3174a3632191f93236d9.tar.gz
core-68daa8a22611605299ac3174a3632191f93236d9.zip
xmloff: std::auto_ptr -> std::unique_ptr
Change-Id: I8baa6c0573af3629bacbf1891c3196c165883d9e
Diffstat (limited to 'include/xmloff/txtparae.hxx')
-rw-r--r--include/xmloff/txtparae.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/xmloff/txtparae.hxx b/include/xmloff/txtparae.hxx
index 2323660455f6..37ec27b42508 100644
--- a/include/xmloff/txtparae.hxx
+++ b/include/xmloff/txtparae.hxx
@@ -76,7 +76,7 @@ class XMLOFF_DLLPUBLIC XMLTextParagraphExport : public XMLStyleExport
rtl::Reference < SvXMLExportPropertyMapper > xSectionPropMapper;
rtl::Reference < SvXMLExportPropertyMapper > xRubyPropMapper;
- const ::std::auto_ptr< ::xmloff::BoundFrameSets > pBoundFrameSets;
+ const ::std::unique_ptr< ::xmloff::BoundFrameSets > pBoundFrameSets;
XMLTextFieldExport *pFieldExport;
std::vector<OUString> *pListElements;
XMLTextListAutoStylePool *pListAutoPool;
@@ -675,7 +675,7 @@ public:
void PopTextListsHelper();
private:
- XMLTextParagraphExport(XMLTextParagraphExport &); // private copy-ctor because of explicit copy-ctor of auto_ptr
+ XMLTextParagraphExport(XMLTextParagraphExport &); // private copy-ctor because of explicit copy-ctor of unique_ptr
};
inline const XMLTextListAutoStylePool&